==> flexible-process-springboot-0.13.1-sources.jar: org/kie/flexible/kogito/example/ServiceDeskModelInput.java <==
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "serviceDesk", name = "ServiceDesk", hidden = true)
public class ServiceDeskModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("supportCase", this.supportCase);
        params.put("supportGroup", this.supportGroup);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        this.supportGroup = (java.lang.String) params.get("supportGroup");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportCase")
    @javax.validation.Valid()
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportGroup")
    @javax.validation.Valid()
    private java.lang.String supportGroup;

    public java.lang.String getSupportGroup() {
        return supportGroup;
    }

    public void setSupportGroup(java.lang.String supportGroup) {
        this.supportGroup = supportGroup;
    }
}

==> flexible-process-springboot-0.14.0-sources.jar: org/kie/flexible/kogito/example/ServiceDeskModelInput.java <==
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "serviceDesk", name = "ServiceDesk", hidden = true)
public class ServiceDeskModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("supportCase", this.supportCase);
        params.put("supportGroup", this.supportGroup);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        this.supportGroup = (java.lang.String) params.get("supportGroup");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportCase")
    @javax.validation.Valid()
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportGroup")
    @javax.validation.Valid()
    private java.lang.String supportGroup;

    public java.lang.String getSupportGroup() {
        return supportGroup;
    }

    public void setSupportGroup(java.lang.String supportGroup) {
        this.supportGroup = supportGroup;
    }

    public ServiceDeskModel toModel() {
        ServiceDeskModel result = new ServiceDeskModel();
        result.setSupportCase(getSupportCase());
        result.setSupportGroup(getSupportGroup());
        return result;
    }
}
